---
output:
  html_document: default
  pdf_document: default
---
# Module 1: Open Principles

*Estimated time to complete: 60 minutes*

*Estimated saving time: A lot*

## Table of Contents

- [Introduction](#introduction)
  - [Who is this module for?](#who_for)
  - [Specific learning objectives for this module](#objectives)
- [What is Open Science?](#what_is)
  - [Community values in Open Science](#values)
  - [History of Open Science and Open Cultures](#cultures)
  - [Differences in understanding and interpretation](#interpretation)
  - [Open Scientists share objects to gain network effects for their work](#network_effects)
- [Principles of Open Science](#principles)
- [The different dimensions of Open Science](#dimensions)
- [How Open Science impacts you; **TASK 1**](#impacts)
  - [Changes in research evaluation](#evaluation)
  - [Potential impact on your career](#career)
  - [Creating your digital profile; **TASK 2**](#profile)
- [Barriers and limitations in Open Science](#barriers)
  - [Moving away from tradition and the status quo](#tradition)
- [Open Science and reproducible research](#reproducible)
- [Making Open Science part of your daily research workflow](#workflow)
- [Where to go from here](#future)
- [Development Team](#development_team)

**BEFORE YOU START**

> Science is everywhere, science is all around us. This is your last chance. After this there is no turning back. You take the [blue pill](https://www.elsevier.com/about/open-science), the story ends, you wake up in your bed, and believe whatever you want to believe. You take the [red pill](#Introduction), you stay in Wonderland, and we show you how deep the rabbit hole goes. (Fishburne, 1999)

Did you know that the Internet and the World Wide Web were both originally designed for research purposes? Researchers wanted a fast, easy, and low-cost way for sharing data with each other, and hence the Internet was born. Now, the Internet dominates almost all aspects of our daily lives, and yet has somehow deviated from this original purpose. Now, research seems to have gone almost backwards compared to every other enterprise - Open Science is the movement to bring modern research back into line with this original digital intent, while reasserting fundamental scientific principles back to the endeavour.

Did you also now that this is so important, that it is even in the [United Nations Declaration on Human Rights](http://www.un.org/en/universal-declaration-human-rights/)?

> (1) Everyone has the right freely to participate in the cultural life of the community, to enjoy the arts and to share in scientific advancement and its benefits.

> (2) Everyone has the right to the protection of the moral and material interests resulting from any scientific, literary or artistic production of which he is the author.

You have probably landed here because you have a nagging feeling that something about the way modern research is conducted and shared is not quite right. This module will hopefully shed some light on those feelings, and help you to understand the state of the present system, and its discord within intrinsic human and scientific values and principles. This is the start of your own journey to become an *awesome* researcher and a *champion* in your field. Hopefully, by being here, we can all work together to empower individuals and communities to make changes to research cultures that we haven't even imagined yet!

<br/>

## Introduction <a name="introduction"></a>

Welcome to Module 1 of the Open Science MOOC: Open Principles. This is the first of 10 core modules to give you a solid grounding in all things Open Science. This module has been developed [in the open](https://github.com/OpenScienceMOOC/Module-1-Open-Principles) through collaboration by an international team of [Open Science wizards](#Development_team).

You, yes you, are in the middle of a profound global scientific revolution. To innovate in a field frequently implies moving against prevailing trends, structures, and cultural inertia. **Open Science** is no different. The fact that *you* are here, reading this now, means that you probably have an interest in the impact that Open Science can have on improving research cultures, and have noticed that something is not quite right about the "status quo" in modern research.

This module will introduce to you the guiding principles, values, and practices of 'Open Science', some of the potential barriers to these, and the positive impact that integrating openness into your daily research work can have on you. This module is not designed to be a 'one size fits all' approach, but rather a foundational plan that incorporates questions around the varying and dynamic dimensions, interpretations, and goals of Open Science across different communities.

<p align="center"><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/02_expectations.png?raw=true" width="400"?raw=true></p>

<p align="center">Image license: CC0 1.0 Universal; Patrick Hochstenbach <a href="https://twitter.com/hochstenbach" target=""

<br/>

### Who is this module for? <a name="who_for"></a>

Designed primarily for students and researchers at the graduate and undergraduate level, this module also serves as training material for postdocs and more senior researchers. We want to help make openness universal and for all, not just a select few. This aims to be a cross-disciplinary module covering all research branches, including Engineering, Medicine, Biosciences, Mathematics, Social Sciences, Humanities, and the Arts.

We have set a highly inclusive standard, and right from the very beginning have had people from across the *whole* spectrum of scholarly research, and related disciplines like tech, publishing, and librarianship, involved in developing and scoping the project. We use the term 'Open Science' given that this seems to be the phrase that global changes are coalescing around; while recognising that terms such as 'Open Research' or 'Open Scholarship', although less widely used, might capture a bit better what our intention is here.

Therefore, irrespective of your background **you are very much welcome here**.

<br/>

> "Open Science describes the practice of carrying out scientific research in a completely transparent manner, and making the results of that research available to everyone. Isn't that just 'science'?!" - Mick Watson-- [(source)](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Watson%2C%202015.pdf)

<br/>

<center><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/open_science.png?raw=true" width="800" /></center>

<p align="center"><i>Melanie Imming, & Jon Tennant. (2018, June 8). Sticker Open Science: just science done right. Zenodo. <a href="https://zenodo.org/record/1285575#.XDebSM17lPY">https://zenodo.org/record/1285575#.XDebSM17lPY</a></i></p>

<br/>

### Specific learning objectives for this module <a name="objectives"></a>

1. Understand the ethical, legal, social, economic, philosophical, and research impact arguments for and against Open Science.

2. Set up a personal profile for defining your impact: Measure the social and academic attention for the full range of your research processes and outputs.
 
<br/>

## What is Open Science? <a name="what_is"></a>

> None of us is as smart as all of us. - Kenneth H. Blanchard.

The term 'Open Science' has not yet a universally accepted definition, but usually refers to one core theme: **Increasing knowledge availability as a public good**, typically with critical research principles such as credibility, reproducibility, and verifiability included in some combination. Many other terms are being used synonymously with Open Science, such as Open Research, Open Scholarship, Science 2.0, and eScience.

Throughout this MOOC, we consider 'Open Science' to be fully inclusive of all of these terms, all scholarly research disciplines, and to reflect the wider process of organised knowledge creation [(Bartling and Friesike, 2014)](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Bartling%20and%20Friesike%2C%202014.pdf).

Ironically, the only current peer-reviewed research article to systematically attempt to define Open Science is paywalled, so we do not include it here. Sigh. (DOI, for those interested: 10.1016/j.jbusres.2017.12.043)

<br/>

> [FOSTER](https://www.fosteropenscience.eu/) defines Open Science as: "The movement to make scientific research, data and dissemination accessible to all levels of an inquiring society."

<br/>

Open Science can broadly be viewed as a way of enhancing scientific progress through sharing of knowledge and methods, wider collaboration, and increased rigour and is indirectly already postulated as part of our/researchers' collective core values and **Good Scientific Practices**. Research can only thrive if it is shared and built upon.

Often, the usage of Open Science seems to be based around three core things: *Processes* (e.g., collaboration, reproducibility), *Products* (e.g., Open Data, Open Materials), and *Values* (e.g., freedom, equity). This seems to form a chain reaction and positive feedback loop, where values drive a particular process, which in turn scopes the products of research.

### Community values in Open Science <a name="values"></a>

The values inherent to Open Science have again not yet been rigorously defined or accepted by the global research community. However, there are a number of inherent values that come up time and time again in discussions of openness. These include: **diversity, inclusivity, fairness, equity, social behaviour, accountability, ethics and responsibility.**

Now, these are not necessarily values that are exclusive to scientific research, and are more human in nature. This is critical, as it helps to frame Open Science as an inherent human nature, and thus amplifies its social importance and imperative.

> How do we use Open Science approaches in the context of retooling our institutions to benefit actual living and breathing humans (scientists and nonscientists)? How can we use Open Science to enable as many people who have the interest and talent to pursue science for it’s own sake and to generate knowledge that is broadly useful for society, and not just elite institutions, venture capital firms or global megacorporations? - Alex Lancaster [(source)](http://ronininstitute.org/open-science-and-its-discontents/).

<br/>

> I am, somehow, less interested in the weight and conviolutions of Einstein's brain than in the near certainty that people of equal talent have lived and died in cotton fields and sweatshops. - Stephen Jay Gould.

[INSERT STATEMENT FROM THE MOOC MISSION HERE ABOUT ACHIEVING THIS ALIGNMENT]

Therefore, some of the key, value-based goals of the Open Science community include:

* **Freely available access to all outputs of the whole research process;**

* **Equity and inclusive participation in research;**

* **Diverse and creative interpretations of scientific results;**

* **Rigorous, transparent, and responsible evaluation of research processes and outcomes;**

* **Collaborative re-use of research outcomes, reducing costs, waste and redundancy;**

* **Comprehensive research practices incentivised through more diverse reward systems;**

* **Accelerated research discovery, innovation and public impact;** and

* **Increasing reproducibility of research results, enhancing trustability and integrity.**

<br/>

If these things are all true, then we have to ask of ourselves: *Why isn't all publicly-funded science practised this way?*

It seems that Open Science is often communicated as an *alternative* to many modern or traditional scientific methods. We argue that Open Science is an *enhancement* of the traditional process, using new knowledge, skills, and technologies to improve how the process and outputs of research are communicated. It is based on fundamental human values around **inclusivity**, **freedom**, and **equity**, embedded as foundational elements to the research process, rather than as an afterthought. These human values are what distinguish 'Open' science from much of the way modern research is viewed and practised. We also believe that virtually everyone who comes into research already has these fundamental values as part of who they are. However, often they become divergent from the way in which the academic system forces them to work. We want to change that.

The foundational elements of traditional research communication, peer-reviewed research articles, act as an important mechanism to summarise and communicate research. Open Science helps to make research articles more rigorous, verifiable and reliable. This helps to enhance public trust in the scientific community and endeavour. In modern society, this has never been more important.

> Open Science is subject to the most rigorous peer review because the process never ends. - [(Woelfle et al., 2011)](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Woelfle%20et%20al.%2C%202011.pdf).

<br/>

Perhaps one of the most important aspect of the Open Science movement in recent years has been the drive behind the liberation of research papers from behind paywalls to be freely available to anyone; also known as Open Access. This has largely been based on the principle that humans deserve to have access to scientific knowledge, and benefit from that.

<center><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/OA.jpg?raw=true" width="800" /></center>

<p align="center"><i>Number of articles (A) and proportion of articles (B) with OA copies, estimated based on a random sample of 100,000 articles with Crossref DOIs. <a href="https://peerj.com/articles/4375/#fig-2">Piwowar et al. (2018)</a></i></p>

<br/>

Still today (2018), most research papers remain locked behind expensive paywalls, critical research data remains hidden away on hard-drives, methods remain often scantly documented, research results cannot be reproduced, and researchers are often evaluated on senseless criteria such as the journal impact factor. These are just some examples of typical practices that contribute to what might be viewed as 'closed science'; or bad (unethical) scientific practices.

Open Science is about changing these research practices through a cultural/paradigm shift. This shift in research culture is often referred to as the [**Scholarly Commons**](https://www.force11.org/group/scholarly-commons-working-group), which seeks to explore and redefine what a modern scholarly communication ecosystem should look like.

Accomplishing a cultural shift on a global scale is **NOT EASY**. Fundamentally, it is usually mainly done through the spread of shared cultural norms and values that are interpreted and celebrated in hundreds of local institutions: in your department, school, laboratory, university, professional association, publishing effort, open software platform developer company, or funding agency. It is a complex, multi-dimensional paradigm to comprehend. Each of these organizations fits itself into the cultural practices that members decide will work best for them to become active in performing the cultural work of Open Science. Culture change *must* start from the ground up. Open Science principles illuminate this ground.

The power of modern Web technologies enables instantaneous sharing and global collaboration in an unrestricted fashion. The digital era is transforming the way in which research is performed, and the limitations on distribution of the print era are largely gone (at least in theory). With this, new issues arise including the complexities of knowledge capture and communication. The framing of these complexities as a 'Commons' integrates the political, social, economic, and philosophical dimensions around knowledge generation and sharing.

Open Science gives rise to a new set of standards, tools, principles, and practices to revolutionise the way we perform and disseminate research knowledge. And we are going to need all of this, if we want to help shape our world for the better.

For example, the United Nations has recently set a number of critical Sustainable Development Goals.

<center><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/UN.png?raw=true" width="800" /></center>

<p align="center"><i><a href="https://sustainabledevelopment.un.org/sdgs">UN Sustainable Development Goals</a></i></p>

<br/>

The question to you is, *do you believe that science can help progress towards reaching these goals?* Hopefully, your answer is a resounding **YES**. But if so, you must also acknowledge that much of the way we often currently practise science in a 'closed' manner means that we are not doing the best that we can to achieve this. Open Science can be a cultural shift that helps to make the world a better place.

<br/>

### History of Open Science and Open Cultures <a name="cultures"></a>

In the 1660s, Robert Boyle, the "father of chemistry," broke with the practices of alchemy in his early writings, e.g., [The Sceptical Chymist](https://en.wikipedia.org/wiki/The_Sceptical_Chymist), and promoted open experimentation (following Roger Bacon's model). Previously, alchemists occulted their methods and their knowledge died with them. What might have been called "open alchemy" became "natural philosophy" and then "science." **Science was born open**. 

The commitment to opening science to help make it more transparent and accessible is nothing new. For some historians of science openness marks the beginning of science itself: with the printing press, the rise of publication markets and empirical methods in the early modern period came both the professionalization of scientists and the institutionalization of the Academies [(David 2008)](https://ssrn.com/abstract=2209188).

The earliest form of Open Science can perhaps trace its origins back the 17th century, and the origins of the academic journal, such as the [Philosophical Transactions of the Royal Society](https://en.wikipedia.org/wiki/Philosophical_Transactions_of_the_Royal_Society). *Transactions* collected and disseminated a broad range of observations and experiment descriptions and spread the work of the Invisible College, the informal gathering of natural philosophers at Oxford and elsewhere. Publication of scientific "news" was also catalysed by an increasing demand for the wider dissemination of scientific knowledge with the wider public. However, the origins can probably go back even further to the very birth of scholarly practices. Much of what we know about our world and universe has foundations in fundamental openness, from evolution and the origin of species, through to gravity and the origins of stars.

<center><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/open_culture.png?raw=true" width="800" /></center>

<p align="center"><i><a>The intersections of Open Science and Open Culture, by Katja Mayer (CC BY)</a></i></p>

<br/>

Although difficult to pin down exactly, the origins of what many call the modern 'Open Science movement' were probably catalysed by increasing frustration, debate, and distress regarding the impacts of 'closed science' (e.g., barriers such as subscription paywalls) and commercialisation of knowledge dissemination by corporate publishers. Indeed, one of the rallying cries of the Open Science movement is that taxpayers who have already paid to fund research should not be having to pay again to read the results of it.

The term "Open Science" itself appears to have been coined by [Steve Mann in 1998](https://en.wikipedia.org/wiki/Open_science#Coining_of_phrase_%22OpenScience%22). Today's "Open Science movement" though probably dates back about 30-40 years, and takes inspiration both from the history of "open source" and the "free software movement" [(Kelty 2008)](https://www.twobits.net/pub/Kelty-TwoBits.pdf) and the ideas developed for research collaboration in the context of "e-science". At a first glance these approaches refer mainly to the technological dimension of opening up science by creating necessary tools and infrastructures. Opening up science often takes the form of a technological liberation and change of techniques in respective discourses. However, keeping in mind that science and technology "are politics by other means" (Bruno Latour, 1978) - offering other means of power - it is vital to turn to the embedded politics of Open Science and its precursors.

In the last two decades, there has been an explosive growth in the development of different aspects of scholarly infrastructure - the core, underpinning aspects of a well-functioning research machine. Much of this is a blend of non-profit and commercial services, which are now variably integrated, but has created a strange and complex new system of ways to perform and communicate research. It is difficult to here to cast judgement on 'for-profit' versus 'not-for-profit' entities with respect to openness in a simple binary way. For example, for-profit entities like [Publons](https://publons.com/) and [Figshare](https://figshare.com/) were important in catalysing changes in crediting peer review and Open Data respectively; while not-for-profits like the [American Chemical Society](https://www.scientificamerican.com/article/open-access-to-science-un/) have actively lobbied against progressive changes around Open Science.

From this, what might (hopefully) be becoming a little more clear is that Open Science is about systemic change. It challenges the way research is conducted, at a practical and cultural level, the way it is evaluated, and the ways in which scientific knowledge is disseminated and integrated into the functioning of society. Much of this is ingrained into research culture through self-reinforcing local governance systems, which are often imposed through external capitalist pressure. For example, the '*publish or perish*' mantra is a direct consequence of these pressures, which in turn are linked to the evolving [neoliberal agenda](https://opinionator.blogs.nytimes.com/2009/03/08/neoliberalism-and-higher-education/) imposed by modern research institutes.

So now, if this makes sense to you, it might seem like Open Science is in almost direct conflict with a capitalistic culture. This conflict is not new to science. In the 1940s, famed sociologist Robert Merton articulated some of the results of his sociology of science research as a set of four norms: principles that described the underlying ethos of science. Each of these norms is sharply divergent to how a free marketplace operates. You can read about the norms [here](https://en.wikipedia.org/wiki/Mertonian_norms). One of Merton's norms was "communism," (this is sometimes re-worded as "communalism"):

> "'Communism,' in the nontechnical and extended sense of common ownership of goods, is a second integral element of the scientific ethos. The substantive findings of science are a product of social collaboration and are assigned to the community. They constitute a common heritage in which the equity of the individual producer is severely limited." - Originally published as “Science and Technology in a Democratic Order,” *Journal of Legal and Political Sociology*, and then later published as “Science and Democratic Social Structure,” in Robert K. Merton, [*Social Theory and Social Structure*](https://en.wikipedia.org/wiki/Social_Theory_and_Social_Structure). A link to a summary version can be found [here](https://www.collier.sts.vt.edu/5424/pdfs/merton_1973.pdf).

The other three [norms](https://scienceblogs.com/ethicsandscience/2008/01/29/basic-concepts-the-norms-of-sc) are:

* Universalism: That researchers should be concerned with the content of claims, not with who made them;
* Disinterestedness: That researchers are in this for more than just personal gain; and
* Organised skepticism: That anyone can potentially advance knowledge claims.

It is good to remember that Open Science principles re-articulate science norms that were historically considered to be integral to research itself. Open Science reaffirms the right of the community to access the substantive findings of research. As the findings of research belong to the entire community, any attempt by individuals or corporations to capture these for profit is a practice based on a notion of equity that is foreign to, and contrary to, how research is meant to operate.

Open Science really hit the mainstream around 2016 due to a number of possible reasons. A combination of political activity and grassroots community-led initiatives put it firmly on the map, and now everywhere you go in science, openness is all around in one way or another.

The production of research knowledge is inherently geopolitical, as emphasised by [The Knowledge Gap](http://knowledgegap.org/). There are strange forces at play that influence representation, mechanisms of distribution, dimensions of power, and structural inequalities throughout the global scholarly communication system. These all contribute towards a complex, and fragmented, global Open Science landscape.

> To see Open Science as a historically produced discourse, we need to first abandon the notion that openness is always inherently positive and/or neutral. We then need to revise and contextualize openness within their particular historical legacies, contexts and and sociopolitical struggles. Denisse Albornoz [(Source)](https://medium.com/@denalbz/power-and-inequality-in-open-science-discourses-9d425b0c2b63).

For example, there has been a strong focus on Open Science in the last few years in Europe, with one of the biggest developments coming from this being the [European Open Science Cloud](http://ec.europa.eu/research/openscience/index.cfm?pg=open-science-cloud) (EOSC). Outside of Europe, there have been strong recent developments across Africa (with the [African Open Science Platform](http://africanopenscience.org.za/)) and [Indonesia](https://blogs.openaire.eu/?p=3105) too. In October 2018, a large group of individuals and organisations across Latin America signed the [Open Science Panama Declaration](http://openaccessweek.org/profiles/blogs/open-scicence-panama-declaration-latin-america-going-beyond-open), emphasising that Open Science really has spread across the global research landscape. Through all of this, researchers and those engaged with the wider Open Science community must make sure to be aware of the geopolitical dimensions around Open Science and knowledge production.

<br/>

### Differences in understanding and interpretation <a name="interpretation"></a>

As mentioned above, there does not seem to be a single accepted definition of what Open Science is. Ask one person, and they will tell you it is about making datasets and research papers public. Ask another, and they will tell you about a vision for a 'radical' transformation of scholarship, where all processes and outputs are instantaneously public. The extent to which different communities and disciplines have embraced and adopted Open Science practices is extremely variable. However, what is clear is that 'Open Science' in one form or another is taking off across the entire research domain, from Arts, Humanities, and [Social Sciences](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Miguel%20et%20al.%2C%202014.pdf) through to Maths, Engineering, and Physical Sciences.

There are two possible ways too look at this. First, some might argue that the power of a definition lies in its precision, and helps to avoid distortion of those definitions - what some might, in this case, call "open washing". Second, flexibility in the definition, and its understanding and interpretation, lead to increased familiarity with a concept as a ['boundary object'](https://journals.openedition.org/rfsic/3220). For the latter, and for Open Science, this means that while it might be interpreted differently across different communities with a variety of norms and practices, the foundational understanding that Open Science is good for public access to knowledge is universally accepted.

There are also [geopolitical](https://medium.com/@denalbz/power-and-inequality-in-open-science-discourses-9d425b0c2b63) differences that shape our understanding of Open Science. For example, in Europe, and much of the industrial world, Open Science often has an inherently market-oriented language that promotes economic value, productivity, and competition, above all other factors. However, for many of those in the 'global south', Open Science is more about fostering community-building through knowledge sharing, and nurturing social networks around new technologies and infrastructures.

<br/>

### Open Scientists share objects to gain network effects for their work <a name="network_effects"></a>

> “Because we have to coordinate with one another to get anything out of our shared free time and talents, using cognitive surplus isn’t just about accumulating individual preferences. The culture of the various groups of users matters enormously for what they expect of one another and how they work together. The culture in turn will determine how much of the value that we get out of the cognitive surplus will be merely communal (enjoyed by the participants, but not of much use for society at large) and how much of it will be civic.” - Excerpt From: Clay Shirky, [Cognitive Surplus](https://en.wikipedia.org/wiki/Cognitive_Surplus).

Building on a civic culture of sharing, Open Science creates new value from every 'object' (idea, data, method, software, results) that is openly shared, releasing the inherent value of the entire research process. Some of this new value accrues to the researcher who shares, some goes to the benefit of all researchers working in the same arena who reuse these objects, and some goes to researchers who can open up new research from the collective resource that these objects now enhance. This last value is the ultimate promise of Open Science: a shared surplus of research objects that can be openly mixed, mined, and melded into new, synthetic knowledge.

[McKiernan et al., (2016)](https://elifesciences.org/articles/16800) demonstrate the advantages of open sharing for increasing citations, impacts, and ultimately the careers of researchers. What the 'open' researcher does to increase the holdings of the open corpus in their field adds a civic choice to these advantages. Growing the open research ecosystem helps every researcher on the planet, while simultaneously making a conscious objective towards making research a public and societal good. Thus, even within traditional systems of research(er) evaluation, the practice of Open Science is inherently beneficial to the individual.

Adding new research findings or experimental methods to an open repository/platform tends to be as easy (or easier) than sharing within a closed collection (such as a for-profit publisher). Open sharing scales better, particularly when it uses open standards-based platforms, such as the [Open Science Framework](https://osf.io/). It also tends to be less fragile, since it can be migrated or ported into new platforms and spread across multiple locations. Openness adds to discoverability and access, and contributes to reproducibility.

**The potential of openness is virtually unlimited in scope!**

Even as the value of, for example, a telephone exchange increases with each new telephone connection, the addition of a new data set, or a null result paper, or a specific finding, builds numerous interconnections with the rest of the global research corpus. These interconnections (and their “network effects”) can lead to the generation of new knowledge, and they can serve as a mirror and a measure to reveal how each new bit of content solves (or critiques) a specific issue, and also potential problems with the newly added object. Rapid open review opportunities arise as well as increased recognition and opportunities for new collaborations.

Many of these network effects will take place on the internet at a planetary scale. The interconnections made possible by Open Science build capacity for the free movement of objects and ideas directly linked back to their authors. This capacity for the almost instant and free global access to research products on the open web is anathema to markets that need to claim ownership and restrict access in order to capture profits from these. Distributed data protocols such as the [Interplanetary File System](https://ipfs.io/) and other emergent technologies will reduce the cost of hosting science objects to a near zero margin. Open licenses make sharing research knowledge durable and its reuse legal.

As [Cameron Neylon](https://en.wikipedia.org/wiki/Cameron_Neylon) said at the metrics breakout of the *Beyond the PDF* conference in 2011, "*reuse is THE metric*".

Why is this? Reuse:

* Reveals and confirms the advantage that open sharing has over many current, market-based, practices;

* Validates the work of the researcher who contributed to the research ecosystem; and

* Captures more of the inherent value of the original discovery and accelerates knowledge growth.

Open Science is a research knowledge and data reuse accelerator. Its network effects help make reuse available, and, in time, inevitable. However, active, open reuse has not been a part of science culture for most scientists today, and the cultural changes that can help Open Science realize the goal of widespread reuse is a major challenge we face.

Of note here is that much of what we are discussing here has only recently become possible due to the rapid advances in Web-based technologies. This does not therefore mean that much historical research was not 'Open Science', as the opportunities simply were not available to researchers then.

<br/>

## Principles of Open Science <a name="principles"></a>

Now, there are no rules about Open Science, and no one individual or organisation is setting the agenda. However, what is commonly recognised is that Open Science is underpinned by specific, core principles and values. In recognition of this, there are now around [100 charters and declarations](https://docs.google.com/spreadsheets/d/1-aRXFiRg-VL9hpLpxoJqX6-OC-A0R2oCogHfIx52Nug/edit#gid=956616118) to do with data sharing and scholarly communication and publishing, and hundreds more [advocacy organisations](http://oad.simmons.edu/oadwiki/Advocacy_organizations_for_OA) that make openness a significant part of their mission.

<center><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/principles.png?raw=true" width="800" /></center>

<p align="center"><i>Principles of Open Scholarship, by Tony Ross-Hellauer (2017; CC BY). <a href="https://www.slideshare.net/OpenAIRE_eu/peer-review-in-the-age-of-open-science"></a></i></p>

Note that often you will find things described as Open Science, but that do not seem to embrace these principles. These things are probably not 'true' Open Science, but more just attempting to surf the wave or join the bandwagon as a PR stunt. The opposite is also true, that many researchers might practice 'openness', but simply choose not to refer to it as this (or are unaware of the relationship).

[![Open & Collaborative Science Manifesto
](https://img.youtube.com/vi/Y1X0xtB_JcY/0.jpg)](https://www.youtube.com/watch?v=Y1X0xtB_JcY)

<p align="center"><i>Open and Collaborative Science Manifesto. This video describes the 7 principles that constitute a more open and inclusive science in development. CC BY <a href="https://www.youtube.com/watch?time_continue=3&v=Y1X0xtB_JcY" >Source</a></i></p>

<br/>

This above video from [OCSDNet](https://ocsdnet.org/manifesto/open-science-manifesto/) is absolutely critical in helping to frame the principles of Open Science. It outlines the importance of representation and inclusivity within Open Science, and the importance of these in challenging the core values of 'traditional' (or modern) science. They propose **seven principles** for Open and Collaborative Science:

* **Principle 1**: Enables a knowledge commons where every individual has the means to decide how their knowledge is governed and managed to address their needs.

* **Principle 2**: It recognizes cognitive justice, the need for diverse understandings of knowledge making to co-exist in scientific production.

* **Principle 3**: It practices situated openness by addressing the ways in which context, power and inequality condition scientific research.

* **Principle 4**: It advocates for every individual's right to research and enables different forms of participation at all stages of the research process.

* **Principle 5**: It fosters equitable collaboration between scientists and social actors and cultivates co-creation and social innovation in society.

* **Principle 6**: It incentivizes inclusive infrastructures that empower people of all abilities to make, and use accessible open-source technologies.

* **Principle 7**: It strives to use knowledge as a pathway to sustainable development, equipping every individual to improve the well-being of our society and planet.

<center><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/ocsdnet_principles.png?raw=true" width="800" /></center>

<p align="center"><i>OCSDNet principles for Open and Collaborative Science.</i></p>

<br/>

Another widely-known vision for the future of open scholarly communication is the [Vienna Principles](https://viennaprinciples.org/). Please feel free to share, re-use, or print these handy little infographics as you wish! Finally, another set of principles worth mentioning here are the [Scholarly Commons](https://osf.io/6c2xt/).

<center><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/vienna_principles.png?raw=true" width="800" /></center>


<p align="center"><i>The Vienna Principles, now in handy infographic form!</i></p>

<br/>

## The different dimensions of Open Science <a name="dimensions"></a>

Open Science, just like 'regular science', is a complicated construct. Thankfully, a lot of great work has already been performed to help frame the different contexts of Open Science. One of the most commonly used is the Open Science taxonomy from FOSTER, shown below:

![FOSTER Open Science taxonomy](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/os_taxonomy.png?raw=true)

<p align="center"><i><a href="https://www.fosteropenscience.eu/about#download" >FOSTER Open Science taxonomy</a></i></p>

<br/>

The different aspects of this will be explored throughout different modules in this MOOC, but here it is worth highlighting just some of the core concepts:

* **OPEN DATA**: Open data is the process of sharing both the original, raw and the treated or processed data online. This helps others to redo your experiments, and re-use it for additional purposes, helping to verify and accelerate research discoveries.

* **OPEN ACCESS**: Allows anyone to access and re-use research published in journal articles without payment or restriction.

* **OPEN PEER REVIEW**: This is a highly dimensional concept, including aspects to do with publishing review reports, revealing the identity of reviewers, and making peer review a more continuous and collaborative process.

* **OPEN METHODS**: Where the process of the research has been documented in a sufficient detail to allow others to *repeat*, *reproduce*, or *replicate* the work.

* **OPEN SOURCE**: Much modern research relies on code and software, and Open Source is about providing free access and re-use rights to this to maximise its utility.

Other critical aspects of Open Science include **Public Engagement with Science**, **Open Educational Resources**, and **Open Advocacy** - all of which will be covered in later modules!

<center><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/moocpng.png?raw=true" width="800" /></center>

<p align="center"><i>Modules covered throughout this MOOC <a href="https://opensciencemooc.github.io/site/Modules/" ></a></i></p>

<br/>

Another popular framing device is the 'Open Science schools of thought', by [Benedikt Fecher and Sascha Friesike](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Fecher%20and%20Friesike%2C%202014.pdf):

1. The **Infrastructure school**, which is concerned with how the architecture of new technologies can help to make a more efficient research enterprise;

2. The **Public school**, regards the accessibility of knowledge creation to a wider audience;

3. The **Measurement school**, concerned with alternative methods of assessing scientific impact development;

4. The **Democratic school**, based around fundamental rights of access to knowledge; and

5. The **Pragmatic school**, concerning the role of collaborative research for more efficient knowledge creation and dissemination.

Recently, the [Foundations for Open Scholarship Strategy Development](https://zenodo.org/record/1323437#.W2bIJSj7RPY) added a 6th to this, the [Community and Inclusion school](https://open-scholarship-strategy.github.io/site/#Community), which is concerned with ensuring a diverse and inclusive community in the Open Scholarship space.

<br/>

## How Open Science impacts you <a name="impacts"></a>

[**GO TO TASK 1: Defining how Open Science affects you**](Task_1.md)

The most comprehensive overview of how Open Science impacts you comes from [McKiernan et al. (2016)](https://elifesciences.org/articles/16800), entitled 'How open science helps researchers succeed.' There's not much point rewriting this, as it does such a good job of making a positive case based on a number of important dimensions already! Here's the abstract:

> Open access, open data, open source and other open scholarship practices are growing in popularity and necessity. However, widespread adoption of these practices has not yet been achieved. One reason is that researchers are uncertain about how sharing their work will affect their careers. We review literature demonstrating that open research is associated with increases in citations, media attention, potential collaborators, job opportunities and funding opportunities. These findings are evidence that open research practices bring significant benefits to researchers relative to more traditional closed practices.

<br/>

<center><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/citation_advantage.jpg?raw=true" width="800" /></center>

<p align="center"><i>The relative citation rate (OA: non-OA) in 19 fields of research. This rate is defined as the mean citation rate of OA articles divided by the mean citation rate of non-OA articles. Multiple points for the same discipline indicate different estimates from the same study, or estimates from several studies. (McKiernan et al., 2016) <a href="https://elifesciences.org/articles/16800" ></a></i></p>

<br/>

### Changes in research evaluation <a name="evaluation"></a>

The world of research evaluation is slowly changing. The way in researchers and their research is assessed governs virtually everything, as this defines the motivation and incentives behind certain behaviours. Typically, the venue of publication (i.e., the journal and its impact factor) have been considered to be of critical importance in research(er) assessment. However, in the last 5 years there has been a surge in uprising against this practice. As [Stephen Curry noted in 2012](http://occamstypewriter.org/scurry/2012/08/13/sick-of-impact-factors/):

> So consider all that we know of impact factors and think on this: if you use impact factors you are statistically illiterate.
* If you include journal impact factors in the list of publications in your cv, you are statistically illiterate.
* If you are judging grant or promotion applications and find yourself scanning the applicant’s publications, checking off the impact factors, you are statistically illiterate.
* If you publish a journal that trumpets its impact factor in adverts or emails, you are statistically illiterate. (If you trumpet that impact factor to three decimal places, there is little hope for you.)
* If you see someone else using impact factors and make no attempt at correction, you connive at statistical illiteracy.


<center><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/impact_factor.jpg?raw=true" width="800" /></center>

<p align="center"><i>All hail the mighty impact factor! Illustration by John R. McKiernan, CC BY <a href="http://whyopenresearch.org/gallery" ></a></i></p>

While there is generally little empirical evidence, it is generally accepted that research evaluation is almost entirely contingent on getting research articles published in 'high impact' journal venues. Strangely, very little empirical evidence exists to demonstrate that this view is actually embedded in practice.

For example, a recent study from [Juan Pablo Alperin and colleagues](https://hcommons.org/deposits/item/hc:21015/) analysed the review, tenure, and promotion guidelines from across a wide range of North American research institutes. What they found was that about 48% of research institutes mention metrics of some sort in these documents, with variations across different institute types.

One consequence of this, is that other elements of the research process, are often seen as less important. This includes Open Science, and forms of wider public engagement, which can be viewed as risky or detrimental to the career choices of an individual research; in particular those who are already disadvantaged/marginalised, or at an earlier stage in their career.

This makes total sense. Researchers, believe it or not, are human. Thus, they are driven by inherent human desires to do things like pay their rent, eat food, pay bills, and provide for their families. In order to do this, they have to keep their jobs. Usually, this means conforming to how they believe they will be assessed, and any external pressures to this are seen as a risk to their livelihoods. This is why, as we discussed above, presenting 'Open Science' as divergent from traditional research processes, as opposed to being enhanced or more beneficial ways of doing things, can actually be inadvertently damaging.

Perhaps a much bigger consequence of this, however, is that we essentially have a system where researchers are rewarded for how many papers they publish, and the brands associated with the venue of publication, which can be detrimental to the value of shared knowledge. For example, research has shown that using journal rank for research assessment is an inherently bad scientific practice, and indeed such a negative impact on research that scholarly journals should be abandoned altogether [(Brembs et al., 2013)](https://www.frontiersin.org/articles/10.3389/fnhum.2013.00291/full). Further research has also shown that journal rank is associated with decreased methodological quality and research reliability, and that the present system of journal hierarchies is an ongoing threat to the entire research system [(Brembs, 2018)](https://www.frontiersin.org/articles/10.3389/fnhum.2018.00037/full).

These issues and criticisms have led to an increasing debate around, and action against, modern research evaluation systems. One of the most significant steps was the development of the [Leiden Manifesto](http://www.leidenmanifesto.org/), which produced 10 simple principles to improve the measurement of research performance. It is presently available in [20 languages](http://www.leidenmanifesto.org/translations.html).

Another important step in research evaluation reform is the San Francisco [Declaration on Research Assessment](https://sfdora.org/), often shortened to DORA. Similarly to the Leiden Manifesto, DORA seeks to improve how research is assessed, and individuals and organisations can sign the declaration to show their support.

<br/>

### Potential impact on your career <a name="career"></a>

Things are changing, though. It is becoming more widely realised that these publication-based incentives are detrimental to the research process, and the health of research culture. For example, this comes from an [advertisement for a professorship at the Ludwig Maximillian University](http://www.nicebread.de/open-science-hiring-practices/), Munich, and is one of the first times that Open Science was made an explicit part of hiring criteria:

> "Our department embraces the values of Open Science and strives for replicable and reproducible research. For this goal we support transparent research with open data, open material, and pre-registrations. Candidates are asked to describe in what way they already pursued and plan to pursue these goals."

Having Open Science as a core value in research departments sends a strong message for a shift in research cultures. More and more universities all the time are including aspects of open scholarship in their promotion and tenure guidelines, including [Virginia Commonwealth University, the University of North Texas, Harvard School of Engineering and Applied Sciences, Purdue University Indianapolis, and more](http://whyopenresearch.org/promotion).

Another thing that researchers like to have in order to carry out their work is funding. Again, open practices are becoming much more widely recognised in the funding application process, and can even help to give researchers an edge, or the ability to qualify for special funds. Such funders include the [Bill and Melinda Gates Foundation, the National Science Foundation (USA), the National Institutes of Health (USA), the European Commission, the Wellcome Trust, and the Shuttleworth Foundation](http://whyopenresearch.org/funding)). (note that the latter partially supported the development of this MOOC!)

<center><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/roarmap.png?raw=true" width="800" /></center>

<p align="center"><i>The Registry of Open Access Repository Mandates and Policies (ROARMAP) is a searchable international registry charting the growth of open access mandates and policies adopted by universities, research institutions and research funders that require or request their researchers to provide open access to their peer-reviewed research article output by depositing it in an open access repository. <a href="http://roarmap.eprints.org/" ></a></i></p>

<br/>

### Creating your digital profile <a name="profile"></a>

Alright, enough talk for now. Or text, anyway. Let's help you build your personal, digital persona that embraces openness! Thankfully, you don't have to start from scratch here, and some smart folks have done a lot of the groundwork for you.

There now exist a range of cool tools that can help you to document your 'open' research practices, and build this in to your own digital researcher profile. Here are some of the most important ones, and then a nice practical task to help you set them up for yourself!

* **ORCID** - This stands for Open Researcher and Contributor ID. ORCID gives you a persistent identifier for you and your research, and is a breeze to integrate with your entire publication record.

* **ImpactStory** - Here, imagine all of the attention your research has received online brought to you in one place, linked with your ORCID profile, and displayed with cool badges and summaries? ImpactStory cleverly does this, and tells you your, er, impact story!

* **Publons** - Don't you just hate it when you do a peer review, and then pretty much no one knows anything about it? Don't you want credit for all your hard work? Publons gives you a place to do that!

* **Open Science Framework** - An open source software project that facilitates open collaboration in science research. Currently also hosts a range of preprint servers.

OK, let's go to Task 2 and get you set up with these.

Before you start, please be aware that Publons recently got acquired by the for-profit company Clarivate Analytics recently. While such acquisitions are fairly commonplace in this ecosystem, we want to make you aware that if you sign up to this organisation, while it does provide a value to you, it also uses you as the product which it uses to sell services. We recognise that some of you might be uncomfortable with this (think Facebook for peer review), and therefore this stage is totally optional based on your own values here.

[**GO TO TASK 2: Developing your digital researcher profile**](Task_2.md)

<br/>

## Barriers and limitations for Open Science <a name="barriers"></a>

Despite the more or less obvious benefits of Open Science practice (as discussed above), there are a range of reasonable concerns and therefore necessary limitations and exceptions to be identified, discussed and implemented in a highly discipline-specific manner. It would be utterly foolish, and not very scientific, of us to rampantly support Open Science without paying due consideration to these.

Such concerns include and are not limited to:

* Release of personal data of and information about individuals;

* Publishing of any sensitive information (for example, bioengineering and medical information);

* Geomapping data of endangered species (flora & fauna);

* Poor formatting of data for re-use;

* Lack of distributed article-processing charge funding;

* Use of proprietary software;

* Financial paywalls imposed by publishers;

* Complex, confusing, and difficult to navigate embargo periods;

* Conflicts between funder and publisher policies;

* Usage restrictions imposed by publisher; and

* Reluctance to publish due to fear of competition.

Another important aspect to note (as has always been) is that each openly released dataset requires a clear description of the context in which the data was raised (i.e., metadata), so that researchers who make use of the freely accessible data apply it in a meaningful analysis and reasonably transferred context. Many of these are discussed further within the [Foundations for Open Scholarship Strategy Development](https://open-scholarship-strategy.github.io/site/#Challenges).

Open Science reflects the intentions of the researchers themselves, and is thereby subject to cultural bias. Open Science is not a perfect system by any means, and operates a hierarchy between different barriers. For example, Open Access seeks to remove barriers such as price for readers and re-use permissions, but often fails to address barriers such as connectivity or language, and also in cases erect new barriers, such as author-facing costs.

This is something which the Open Science movement is becoming more and more aware of, especially regarding the risks and impacts that progress towards Open Science can have, particularly on marginalised demographics or already higher-risk communities. Some of the major barriers towards Open Science include:

* Forcing junior researchers to share their data at point of first publication, potentially compromising their future research based on those data;

* High article processing charges (APCs) for publication, that discriminate against those without financial privilege;

* Other [geopolitical factors](https://medium.com/@denalbz/power-and-inequality-in-open-science-discourses-9d425b0c2b63) include resistance to sharing due to fear of persecution, and knowledge misuse or appropriation;

* Evidence. Researchers are generally conservative to adoption of new approaches, until there is sufficient evidence that they are superior than traditional methods.

However, as well as these, there are several worrying and ongoing trends that reflect more systemic issues within Open Science, and scholarship more generally:

* That Open Science is introducing more metrics to 'incentivise' researchers to work harder, at the cost of true productivity and creativity, and not always in their best interests;

* That new gate-keepers are consolidating these metrics, and using them to define the future of research, ending up with a system operating more like a business than an exploratory venture;

* The increasing capture of research and infrastructure by commercial, for-profit entities, reflecting the increasing neoliberal market organisation around science and higher education;

* These same entities often having a parasitic relationship with researchers, who provide labour, services, and content for free to help them build profits;

* A lack of job stability or security and resources, which acts against innovation or any form of risk-taking;

* A lack of consideration of the social and cultural real-world benefits of research; and

* The fact that most historical research still remains locked away from access or re-use.

Based on this, it is interesting to ask why such dangerous trends seem to grow from seemingly good intentions based on positive core principles and values. It might be easy, based on the above, to become extremely pessimistic, or even antagonistic, towards Open Science. However, as with any movement or new way of doing things, it is down to each of us to carefully balance the potential drawbacks and benefits, and the wider consequences and contexts of these.

While the core principles underlying Open Science are often focussed around accessibility, in practice there is often a trade-off within this hierarchy, and often with unforeseen consequences. Much of this is not due to the intentions of Open Science, but more about the difficulties in reconciling the different stakeholder viewpoints, which often leads to inherent conflict and complications around developments.

It is perfectly natural for researchers and industries that have made themselves successful or profitable based on a particular set of practices to resist any disruption towards that. Let us take several primary examples for this.

1. Moving research evaluation away from journal brands and the impact factor.

Imagine if you are a researcher who has built a successful career, to some extent based on the journals in which you have published your work. Then imagine someone says that journal brands, impact factors, and journal ranks are actually bad for science, and don't tell us much about the quality of your research. There's a chance you're going to resist that a bit.

Now, imagine if you are a commercial publisher. Selling your brand to libraries, funders, research assessment groups, and researchers it critical for the financial sustainability and integrity of your journal. Simply removing all concept of brands for your, er, brands, is not exactly a path to fiscal sustainability.

> “We also aim at increasing APCs by increasing the value we offer to authors through improving the impact factor and reputation of our existing journals.” - Springer Nature IPO ([page 99](http://web.archive.org/web/20180507134223/http:/proxy.dbagproject.de/mediacenter/ressourcen/pdf/emissionen/springernature_prospectus.pdf)).

Does this sound like a company who has the best interests of researchers, the public, and open science at heart? So there are major tensions here, that reflect inherent power dynamics within the scholarly communication system. Which perhaps explains why it has been so difficult to move away from an impact factor or journal dominated system since the advent of Open Science. At least part of this can be explained by a largely [dysfunctional scholarly publishing 'market'](https://zenodo.org/record/1472045#.W-7r8ZP7RPY).

2. Moving away from a subscription model to one where all information is freely available.

Did you know that back in 2007, publishers such as Elsevier, Wiley, and the American Chemical Society were advised by the ['pitbull of PR'](https://www.nature.com/articles/445347a) to equate public/open access with government censorship, and for traditional subscription-based publishing with peer review? This is just one small part of a long history where some in the scholarly publishing industry have lobbied and ran smear campaigns against open access, as a delay tactic until they could find a way to either destroy it, or convert it into a profitable business model. This resistance perhaps is one of the key factors in explaining why, in after about 20 years of relentless campaigning, we have only made about 25% of the world's research openly accessible, with the rest locked behind expensive paywalls.

<br/>

## Open Science and reproducible research <a name="profile"></a>

There is an enormous overlap between Open Science and reproducible research. Now, traditionally, much of the research process, as well as the outputs, remain hidden or closed from public scrutiny. Open Science attempts to expose some of this process; for example, by recording and documenting 'failed' reactions, highlighting repeated experiments and their variants, and revealing thoughts, ideas, and comments that were part of the process but wouldn't make into a final research paper.

It might help to imagine Open Science practices as having a magnifying glass or webcam pointing at your research all the time. This helps to 'expose' the process, increase care, and lead to a well-documented process that others can copy and replicate if needed. This is an inherently social process, but comes with an important consideration:

**Research is not a perfect process.**

This might be difficult to accept for many of us, as typically the research we read about in papers or in the media is just the 'positive' aspects, with all of the gritty bits hidden from public view. We all know that research is imperfect, and we should learn to embrace and communicate failure as an inherent part of that process.

All of these elements can be documented as part of a 'lab notebook', and comes with an important implication: **The aspects of research that did not produce favourable results are just as important as those which do.**

Here, the intersection of reproducibility and Open Science becomes centred around one a core value we discussed before: **Freedom and Liberation**. As [Frankenhuis and Nettle, (2018)](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Frankenhuis%20and%20Nettle%2C%202018.pdf) describe, the practices of Open Science are liberating to individuals because they:

1. Enable transparent and comfortable exploration of data;

2. Reward quality, which is under our control, rather than outcomes, which are not;

3. Reduce the demand for "positive" results required for career advancement;

4. Cultivate a flexible and open mindset;

5. Enable a more constructive and collaborative research climate; and

6. Generates more accurate information that is ultimately more accessible.

Therefore, one could easily argue that Open Science is aligned with concepts of **academic freedom**, by liberating individuals from the constraints of the closed system. We will explore the links between Open Science and reproducible research more in [Module 3](https://opensciencemooc.eu/modules/reproducible-research-and-data-analysis/).

<br/>

## Making Open Science part of your daily research workflow <a name="workflow"></a>

As you might now see, Open Science impacts almost every aspect of your typical research workflow. We all think, we all gather data and analyse it, and we usually want to share the results of this with virtually anyone who will listen and re-use it. There are a number of tools, services, platforms, and practices for you to engage with, and this will likely differ for each individual, lab group, or community.

There are no set rules though. Open Science gives you the freedom to explore processes that work best for you, your research, and the impact that can have on your wider community. Below is just one combination of examples of tools that can make your research workflow more open all the way from an initial grant proposal through to research assessment.

![Rainbow of Open Science Practices](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/rainbow-of-open-science-practices.png?raw=true)

<p align="center"><i>Kramer, Bianca, & Bosman, Jeroen. (2018, January). Rainbow of Open Science practices. Zenodo. <a href="http://doi.org/10.5281/zenodo.1147025" >http://doi.org/10.5281/zenodo.1147025</a></i></p>

<br/>

Throughout the rest of this [MOOC](https://opensciencemooc.eu/), you will meet many of these on your Open Science adventure, and tailor new knowledge and skills to suit what is best for you.

<br/>

## Where to go from here <a name="future"></a>

Hopefully now you have come to see the importance of Open Science as a fundamental part of modern research. Open Science is an umbrella term for a range of ideals, values, practices, and principles, all of which are integrated together:

[![Intersections of Openness
](https://img.youtube.com/vi/Es7qvO_2kSg/0.jpg)](https://www.youtube.com/watch?v=Es7qvO_2kSg)

<p align="center"><i>Intersections of Openness: Open Access, Science, & Education. By Abby Elder, CC BY 4.0 International License. <a href="https://www.youtube.com/watch?v=Es7qvO_2kSg" >Source</a></i></p>

The **learning outcomes** from this for you should be:

* You will now be able to describe some of the ethical, social, cultural, and research impact arguments for and against Open Science.

* After deciding which platforms/tools/services are most useful for yourself and your community, you will be able to develop a personal profile for showcasing their research profile and outputs.

* After reflecting on the status of Open Science within your research group or lab, you will help to devise concrete ways to locally improve open practices.

* Using the guidelines published by your research laboratories, departments, or institutes, you will be able to help identify the practices and policies for career progression and assessment, publishing and Open Access, and data sharing.

* You will be able to further collaborate with colleagues and international peers to develop a shared definition of Open Science.

From these, what you will hopefully now have are the foundational best practices and knowledge needed to engage in Open Science. Some small, tangible steps you can take from here to make a real difference here include:

1. Whenever possible, use and cite existing public data;

2. When you can, share your research data through a trusted online repository;

3. Make sure to release source code and scripts used for your analyses, including the environment needed to run them;

4. Post free copies of your research articles online however possible;

5. Share preprints of your research articles online, ideally at the time of journal submission; and

6. If you can, choose an Open Access journal to publish your research articles.

These are adapted from [(Masuzzo and Martens, 2017)](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Masuzzo%20and%20Martens%2C%202017.pdf), and just scratch the surface of the full power of Open Science.

To learn more, visit the remaining 9 modules! This is the perfect chance for individuals, such as yourself, to take action and seize the initiative to become a champion in your research field.

> Open Science is the future, and it will replace closed science. I encourage you to embrace it. - [Mick Watson]((https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Watson%2C%202015.pdf)).

<br/>

### Further reading <a name="Reading"></a>

There is so much potential material out there that it would take years of continuous reading to get through it all. Here are some favourite selected research articles on the topic that help to go into things a little deeper, and provide great overviews of much of what we have discussed here. All of them are free to access and re-use, of course!

* [Open Science is a research accelerator](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Woelfle%20et%20al.%2C%202011.pdf) (Woelfle et al., 2011).

* [Open Science: The Evolving Guide on How the Internet is Changing Research, Collaboration and Scholarly Publishing](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Bartling%20and%20Friesike%2C%202014.pdf) (Bartling and Friesike, 2014).

* [Open Science: one term, five schools of thought](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Fecher%20and%20Friesike%2C%202014.pdf) (Fecher and Friesike, 2014).

* [Winning Research Grants with Open Science](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Grigorov%20et%20al.%2C%202015.pdf) (Grigorov et al., 2015).

* [Promoting transparency in social science research](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Miguel%20et%20al.%2C%202014.pdf) (Miguel et al., 2014).

* [Promoting an open research culture](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Nosek%20et%20al.%2C%202015.pdf) (Nosek et al., 2015).

* [When will 'Open Science' become simply 'science'?](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Watson%2C%202015.pdf) (Watson, 2015).

* [Do you speak Open Science? Resources and tips to learn the language](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Masuzzo%20and%20Martens%2C%202017.pdf) (Masuzzo and Martens, 2017).

* [Early-career researchers' perceptions of the prevalence of questionable research practices, potential causes, and Open Science](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/St%C3%BCrmer%20et%20al.%2C%202017.pdf) (Starmer et al., 2017).

* [Making Science Transparent By Default; Introducing the TOP Statement](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Aalbersberg%20et%20al.%2C%202018.pdf) (Aalbersberg et al., 2018).

* [Defining success in Open Science](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Ali-Khan%20et%20al.%2C%202018.pdf) (Ali-Khan et al., 2018).

* [Open Science is liberating and can foster creativity](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Frankenhuis%20and%20Nettle%2C%202018.pdf) (Frankenhuis and Nettle, 2018).

* [Digital Open Science-Teaching digital tools for reproducible and transparent research](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/Reading%20Material_Open%20Principles/Toelch%20and%20Oswald%2C%202018.pdf) (Toelch and Oswald, 2018).

<br/>

### Development Team <a name="Development_team"></a>

- [Gareth O'Neill](https://twitter.com/gtoneill), Language Lubber
- [Bruce Caron](https://twitter.com/junanaguy), Culture Work Architect
- [Jo Havemann](https://twitter.com/johave), #ResearchinAfrica Highlighter
- [Jon Tennant](https://twitter.com/protohedgehog), Dinosaur Whisperer.

<br/>

### Additional tools and services

* The [FOSTER Open Science Training courses](https://www.fosteropenscience.eu/toolkit) are an excellent series for developing your Open Science skills. Each course takes about 1-2 hours to work through and you'll receive a badge upon completion. The courses include practical tips on getting started with Open Science as well as providing information on discipline specific tools and resources you can use.

* The [Joint Roadmap for Open Science Tools](http://jrost.org/), a community working link together existing Open Science platforms and services into a unified infrastructure.

* The [Open Research Glossary](http://www.righttoresearch.org/resources/OpenResearchGlossary/index.shtml), designed to help provide some insight into some of the language surrounding 'Open Scholarship'.

* The Berkeley Initiative for Transparency in Social Sciences (BITSS) have an excellent MOOC on [Transparent and Open Social Science](https://www.bitss.org/events/mooc-transparent-and-open-social-science/).

* The [Scholarly Communication](https://www.scienceopen.com/search#collection/69988c7e-1855-4007-ba94-caa4c4638b1f) Super Collection at ScienceOpen contains more than 1000 research articles, thematically organised on the topic. Most of these are also Open Access.

* [Why Open Research?](http://whyopenresearch.org/) is a fantastic website by [Erin McKiernan](https://twitter.com/emckiernan13), providing illustrations and information that help to support a strong case for Open Research.

* The [Foundations for Open Scholarship Strategy Development](https://open-scholarship-strategy.github.io/site/), a document that aims to agree on a broad, international strategy for the implementation of open scholarship that meets the needs of different national and regional communities but works globally.

* [Open Science: Sharing Your Research with the World](https://www.edx.org/course/open-science-sharing-your-research-with-the-world) - A MOOC hosted by TU Delft through edX.

* This [incredible visualisation](http://www.markhooper.io/openscience/#-1:0100000000) of the Open Science landscape by Mark Hooper. Mark was also the one who designed the original logos for our MOOC!

**Know a way this content can be improved?**

Time to take your new GitHub skills for a test-run! All content development primarily happens [here](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/MAIN.md). If you have a suggested improvement to the content, layout, or anything else, you can make it and then it will automatically become part of the MOOC content after verification from a moderator!

[![CC0 Public Domain Dedication](https://img.shields.io/badge/License-CC0%201.0-lightgrey.svg)](https://creativecommons.org/publicdomain/zero/1.0/)
