---
output:
  html_document: default
  word_document: default
  pdf_document: default
---

# Task 2: Developing your digital researcher profile

**You are more than just your publications.**

This task is designed for researchers who want to help to build their online profile while helping to amplify their work. Think of this task like a way of creating an online CV for showcasing your research.

Estimated time to complete: 30 minutes.

Estimated time saved: Immeasurable, but probably a lot.

Don't forget you can join in the discussions over at our open [**Slack channel**](https://openmooc-ers-slackin.herokuapp.com/). Please do introduce yourself at #module1principles, and tell us a bit about who you are, your background, and how you ended up here!

## Table of contents

* [Getting started](#Getting_started)
* [Getting your ORCID account](#ORCID)
  * [How to register for your ORCID account](#reg_orcid)
  * [Populating your ORCID profile](#pop_orcid)
* [Create your own Impact Story](#impactstory)
  * [Understanding your own Impactstory profile](#impactstory_profile)
* [Build your peer reviewer profile with Publons](#publons)
  * [Getting your own Publons profile](#publons_account)
  * [Populating your new Publons profile](#publons_profile)
  * [Import your own publication record from ORCID](#ORCID_publons_import)
* [Opening up your research with the Open Science Framework](#osf)

<br/>

## Getting started <a name="Getting_started"></a>

OK, so in the [main content](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/MAIN.md) for this module, we just briefly introduced you to several services that you can use to enhance our researcher profile. These are based around documenting your research publications, the online attention these get, your peer reviewer profile, and research collaboration in the open.

These are by no means the only platforms available to you, and not limited in scope to documenting your own worth as a researcher. However, what they do help to do is give you a better idea of how your researcher profile is developing, and allow others to see that too.

The four we met before are:

* [**ORCID**](https://orcid.org/) - A persistent identifier for you and your research.

* [**ImpactStory**](http://impactstory.org/) - A place to document how your research has been shared and re-used online.

* [**Publons**](https://publons.com/home/) - A place to document your peer review activities.

* [**Open Science Framework**](https://osf.io/) - A place to openly collaborate on your research.

The latter three of these actually integrate nicely with ORCID, including pulling in all the information there to make building your profile a bit easier. Here, we are going to go through each one and help to showcase your work, build your own unique research profile, and be a more open researcher! 

<br/>

## Getting your ORCID account<a name="ORCID"></a>

[ORCID](https://orcid.org/) stands for 'Open Researcher and Contributor ID'. It provides you with a persistent digital identifier that distinguishes you from every other researcher. It also neatly integrates with key research workflows such as manuscript and grant submission, supports automated linkages between you and your professional activities ensuring that your work is recognized. Many journals now require you to have an ORCID profile when submitting manuscripts for publication.

<p align="center"><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/orcid.png?raw=true" width="600" /></p>

<p align="center"><i>3 simple steps to distinguish yourself</i></p>

<br/>

### How to register for your ORCID account<a name="reg_orcid"></a>

This one is quite easy, and only takes a couple of minutes thankfully! Here's how in a few simple steps:

1. Go to the [ORCID website](https://orcid.org/) and click the 'Register now' link.

2. Enter your name, email address, and password.

3. Choose your visibility settings. You can change these for each item in your ORCID profile later if needed.

4. Register.

That's it! Congratulations, you now have a unique and permanent ID for your research profile! Throughout your research workflow, you'll notice ORCID coming up more and more, and now you will be well prepared for when it does.

<br/>

### Populating your ORCID profile<a name="pop_orcid"></a>

OK, so now you have your ORCID profile, it's time to add some content to it! There are several key areas here:

* Education

* Employment

* Funding

* Works (e.g., papers, posters)

* Peer reviews

We'll get to the latter of these later via Publons. For the other four, this is just like any other profile generation that you've done before. In each section of your profile, there is a little button that says, for example **+Add education**. Simply click this, and then **+Add manually**, and then enter the information as normal.

<p align="center"><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/education_orcid.png?raw=true" width="600" /></p>

<p align="center"><i>How to update your ORCID profile</i></p>

<br/>

The great advantage that ORCID has here is that this information can be ported into other systems, so stops you having to enter the same data over and over again across different platforms. Which as well all know can be tiring and frustrating. Here, you can also enter information such as your country of residence, keywords, your website, emails, and other IDs that you might have. It's a good idea here to enter a nice, simple, but comprehensive and professional biography.

For now, there are three ways to help add scholarly works to your ORCID record.

1. Direct import from other systems;

2. Import/export via BibTeX; and

3. Manual addition.

<br/>

<p align="center"><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/works_orcid.png?raw=true" width="600" /></p>

<p align="center"><i>How to update the 'works' associated with your ORCID profile</i></p>

<br/>

Here are a few simple steps for each to help you get familiar with the process.

**DIRECT IMPORT**

1. Click the **Search and link** option.

2. Define the work type and geographical area. Each time you select one of these, it will change the organization options available for you.

3. Each time you click one of the options, it will take you to the 'oauth' authorization page. Here, make sure only to authorize sources that you trust (which is basically all options) to help keep your data safe.

4. After authorizing, you will be taken to the relevant search page for whichever organization you chose (e.g., CrossRef), automatically populated with a search result for your name.

5. Now you can simple select which works you want to be added to your own personal profile.

6. Repeat as needed for each organization until you are happy.

<p align="center"><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/link_orcid.png?raw=true" width="600" /></p>

<p align="center"><i>How to directly integrate works from other systems into your ORCID profile</i></p>

<br/>

**BIBTEX IMPORT**

This one is a bit simpler. If you have a personal citation record as a .bib file (BibTeX file format; for example from [Zotero](https://www.zotero.org/)), you can simply select this from your desktop and upload it. ORCID will do the rest and populate your profile using this. You can use services like the export functions in Google Scholar to make this even easier for yourself too.

You can also export your works here in .bib format.  BibTeX is a platform-independent, plain-text format used for bibliographic citations. BibTeX files can be created and edited using many popular reference management tools, such as Zotero, so is really handy!

<br/>

**MANUAL ADDITION**

This one is even simpler. Pop to your profile, click **Add works**, then **+Add manually**. A box should pop up that enables you to enter information as you need. This is generally best for items that don't get integrated using the other two techniques. Try to add as much detail here as possible to be comprehensive.

Allowing trusted organizations to add information to your record ensures the data connected with your ORCID profile is authoritative and trustworthy, as well as saving you time entering information manually. The organization which added the work to your record will be listed as the source of the item. Often, when your work is indexed in one of these organizations, it will automatically integrated with your profile, helping to keep everything up to date.

<br/>

## Create your own Impact Story<a name="impactstory"></a>

Now that you've created your own ORCID profile, these next steps are going to be easy peasy.

Impactstory is a non-profit dedicated to making scholarly research more open, accessible, and reusable. It helps to provide a fun and lightweight profile that integrates social media mentions, badges, and more with your ORCID record.

Head on over the [Impactstory website](https://profiles.impactstory.org/). Here, you can join for free using Twitter. If you don't have a Twitter account yet, no worries. It's worth setting one up here for now though, as we will revisit this later on in the MOOC.

After logging in with Twitter, you can link it directly and authorise Impactstory to use your ORCID profile that you just created in the settings. That's pretty much it!

In the future, you can make sure your profile is up to date in the Impactstory settings by syncing data from ORCID. It does this automatically, but you can manually update it too, for example whenever you publish a new paper.

<p align="center"><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/orcid_impactstory.png?raw=true" width="600" /></p>

<p align="center"><i>Syncing your Impactstory profile with ORCID is simple and takes seconds</i></p>

<br/>

### Understanding your own Impactstory profile<a name="impactstory_profile"></a>

Your new profile has 4 main tabs:

1. **Overview** - The main page that summarises the over three sections.

2. **Achievements** - Your badges! These document your success story, including great things like how many of your papers are Open Access, how many are included in Wikipedia, the geographic reach of your work, and, er, whether or not your work has been tweeted by someone named Richard. Proceed with caution..

3. **Timeline** - Regular updates on how and who has been sharing your work across a variety of social platforms, including Twitter, Facebook, Google Plus, blogs, and Wikipedia.

4. **Publications** - Based on your publication list from ORCID, with details on all the social media shares for each item.

<p align="center"><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/impactstory_profile.png?raw=true" width="600" /></p>

<p align="center"><i>Syncing your Impactstory profile with ORCID is simple and takes seconds</i></p>

<br/>

The timeline here is important, as it gives you regular updates about who is sharing your work online, what they are saying about it, and where they are sharing. This can help you to understand the wider context of the impact your work is making, and open up numerous new collaboration and communication channels for you.

That's it! As Impactstory say, you are more than your h-index, and this provides a wonderful place for you to document how your research is being used in different contexts.

## Build your peer reviewer profile with Publons<a name="publons"></a>

[Publons](https://publons.com/) is a platform for researchers to track, verify, and showcase their reviewing and editorial contributions for academic journals. It also has the Publons Academy, designed to help with training early-career researchers with peer review.

**IMPORTANT NOTE** In 2017, Publons was acquired by Clarivate Analytics, the company which includes products such as Web of Science (and the impact factor), EndNote, and ScholarOne. At this stage, some of you might not wish to have a profile with this company for various reasons. We make no judgement call on this, and it is up to each individual to decide whether or not they wish to proceed here. At the present though, there is no 'open' (e.g., non-profit, open source) version of or alternative to Publons in existence. If you wish, you can skip this section and head to the next for the [Open Science Framework](#osf).

<br/>

### Getting your own Publons profile<a name="publons_account"></a>

So, assuming that you are okay with the note above, head on over to the [Publons homepage](https://publons.com/home/). Click the 'Create a review profile' button.

<p align="center"><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/publons.png?raw=true" width="800" /></p>

<p align="center"><i>Publons homepage</i></p>

<br/>

Oh, hey, look how useful this is - again you get to register using your ORCID profile! Or Google or LinkedIn accounts if you prefer. For now, let's stick with ORCID though. If you click the green ORCID 'ID' logo, it will take you to the ORCID page where you will be prompted to login. Simply sign in, and then you will be redirected back to your new Publons dashboard. Easy!

<br/>

### Populating your new Publons profile <a name="publons_profile"></a>

On your dashboard now, you'll have several key sections. The first is your public profile, which you can download and edit, and keeps track of your reviewer statistics. The second is your account activity, which includes any notifications as well as any records that are being processed to be added to your profile.

The next section, Records, is where all the fun happens. This is where the most important aspect of your Publons profile is populated, your reviewer record.

<p align="center"><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/publons_add.png?raw=true" width="800" /></p>

<p align="center"><i>Adding a new review record on your Publons dashboard</i></p>

If you haven't performed a peer review yet, don't worry about this stage! But it is nice to be prepared for when it happens.

If you have, there are some simple steps to follow here.

1. Decide if your peer review is 'pre-publication' or 'post-publication'. The vast majority will be the first here.

2. Enter the name of the journal or conference you performed the review for, as well as the date you submitted it.

3. Enter the article title and the DOI (Digital Object Identifier). If the article has not been published yet, there most likely won't be a DOI yet, but don't worry about that.

4. Decide the level of overall review privacy. This includes whether or not you can display the review content itself or not, which is often contingent on the editorial policy of the journal. Publons often has an automatic checking procedure in place for this too.

5. Copy and paste in the review content itself, if you wish. This stage is optional, and again whether or not it will be publicly displayed is based on the editorial policy of the journal. Make sure that you know your sharing rights, as well as the journal policy regarding this, before sharing anything openly.

6. Create the review!

7. This will take you to a new page, where you will have options such as getting your review endorsed and verified, scoring the publication, as well as for inviting further feedback on your review. 

8. Repeat steps 1-7 as necessary. This all does have to be done manually at this stage, but thankfully each record only takes a few minutes to add.

<p align="center"><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/publons_profile.png?raw=true" width="800" /></p>

<p align="center"><i>What a populated Publons record looks like</i></p>

<br/>

After you have added one or more records to your profile, you will see a full visualisation of it on your dashboard. This includes a table with key information, such as:

* The date the review was performed;

* Which journal the review was for;

* The title of the paper you reviewed;

* Whether or not the review was verified;

* Whether the content of the review is publicly displayed or not;

* Whether you have scored the manuscript your reviewed or not;

* If someone has endorsed your review;

* Whether anyone has provided any feedback on your review; and

* The [Altmetric](https://www.altmetric.com/) score for the manuscript.

<br/>

### Import your own publiation record from ORCID<a name="ORCID_publons_import"></a>

After you have populated your reviewer record, you might also wish to import your own publication record from ORCID. This will provide additional information from Publons about the review activity around it, including whether the reviews are openly available or not, whether the reviews have been signed, and the number of citations (based on Web of Science data).

To do this step, simply click 'Publication records' on the left hand side, and then 'Import from ORCID' to populate your publication profile.

<p align="center"><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/publons_pub_record.png?raw=true" width="800" /></p>

<p align="center"><i>Example of a populated Publons publication record</i></p>

<br/>

These are perhaps the most important aspects of Publons for now for researchers. You can also add your records for work as an Editor, and create a Publons widget to display on your website, should you wish. Finally, if you wish to learn more about peer review, the [Publons Academy](https://publons.com/academy/module/1/) provides a training platform for this. We will revisit peer review in Module 7 of the MOOC, [Open Evaluation](https://opensciencemooc.eu/modules/open-evaluation/).

<br/>

## Opening up your research with the Open Science Framework<a name="osf"></a>

OK, hopefully you're getting the hang of this by now! Head to the [Open Science Framework homepage](https://osf.io/), and click 'Sign up'.

<p align="center"><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/osf.png?raw=true" width="600" /></p>

<p align="center"><i>The Open Science Framework homepage</i></p>

<br/>

Again, you should have a chance here to sign in or sign up using your ORCID profile, or through an institutional profile. Once logged in, you will be taken to your dashboard, which contains a rolling list of the various projects integrated with your OSF profile. Of course, if you have only just set up your account this will be blank for now. For a quick, 2 minute video on how to get started with your OSF account, check out the video below.

[![Getting started with the Open Science Framework
](https://img.youtube.com/vi/2TV21gOzfhw/0.jpg)](https://www.youtube.com/watch?v=2TV21gOzfhw)

<p align="center"><i>Getting started with the Open Science Framework, Center for Open Science, CC BY. <a href="https://www.youtube.com/watch?v=2TV21gOzfhw" target="_blank">Source</a></i></p>

<br/>

Perhaps one of the most important things to note here is that the OSF is integrated with a whole host of existing services, including GitHub and Google Drive, that make it a lot easier to use for collaboration and project management. 

> Fun extra! If at this stage you have already completed Task 1 of Module 5, on how to [set up your first GitHub project](https://github.com/OpenScienceMOOC/Module-5-Open-Research-Software-and-Open-Source/blob/master/content_development/Task_1.md), you can take a quick look here and see how easy it is to integrate this into a new or existing project on the OSF. 

<p align="center"><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/osf_integrations.png?raw=true" width="800" /></p>

<p align="center"><i>The Open Science Framework is integrated with a range of other useful services for researchers</i></p>

<br/>

Besides the main project management and collaboration functionalities which you can play with above, the OSF also has four more major features:

1. [OSF Registries](https://osf.io/registries/) - Which includes more than 270,000 registrations, which you can learn more about [here](https://cos.io/prereg/).

2. [OSF Meetings](https://osf.io/meetings/) - A place where conference organisers can arrange a free poster and presentation sharing service for their events.

3. [OSF Institutions](https://osf.io/institutions/) - Basically the OSF, but operating at the institutional level to increase transparency, collaboration, and visibility of research.

4. [OSF Preprints](https://osf.io/preprints/) - A searchable database of more than 2 million preprints, across more than 20 OSF-branded and community-governed platforms.

<p align="center"><img src="https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/images/osf_preprints.png?raw=true" width="800" /></p>

<p align="center"><i>The OSF hosts a huge number of branded and community-governed preprint platforms. Some are subject-specific, while others cater to particular languages. </i></p>

<br/>

## Checklist <a name="Checklist"></a>

**CONGRATULATIONS!**

So hopefully now you have the basics elements of your personalised, online researcher profile completed. This provides a great way to showcase your work, increase and track your research impact, and receive appropriate credit for all of this.

Just to make sure, now you should have:

- [ ] A personal ORCID profile, with any publications associated with this.
- [ ] An ImpactStory profile to help track and showcase the social attention that your research gets.
- [ ] An Open Science Framework profile, to begin openly collaborating and managing your research.
- [ ] And optionally, a Publons profile, to track your peer review record.

From here on, much of this will be automatically populated as your work progresses. But some advice is to check your ImpactStory regularly, to see who is sharing your work and in what context, and to make sure that as much of your research is openly available (e.g., code, articles, data) via the Open Science Framework as possible. Finally, if you created a Publons profile, make sure to update this as you review new articles in the future to keep track of this important work.

How you develop your own digital research profile in the future will be down to each individual, but hopefully this is enough for now to give you a good boost!

<br/>

**Know a way this content can be improved?**

Time to take your new GitHub skills for a test-run! All content development primarily happens [here](https://github.com/OpenScienceMOOC/Module-1-Open-Principles/blob/master/content_development/Task_2.md). If you have a suggested improvement to the content, layout, or anything else, you can make it and then it will automatically become part of the MOOC content after verification from a moderator!

**DISCLAIMER** ORCID, ImpactStory, and the OSF are [strategic partners](https://opensciencemooc.eu/about/) with the Open Science MOOC. We are not supported by them in any way, including financially, and they had no role in the design of this task, or any of this MOOC module. We just think they're all pretty cool.

[![CC0 Public Domain Dedication](https://img.shields.io/badge/License-CC0%201.0-lightgrey.svg)](https://creativecommons.org/publicdomain/zero/1.0/)