# MOOC module design protocol

This protocol will guide you through the the activities for developing modules for the Open Science MOOC.

This is a collaborative, team-based effort. Each module has its own repo on GitHub:

1. [Open Principles](https://github.com/OpenScienceMOOC/Module-1-Open-Principles)
2. [Open Collaboration](https://github.com/OpenScienceMOOC/Module-2-Collaborative-Platforms)
3. [Reproducible Research and Data Analysis](https://github.com/OpenScienceMOOC/Module-3-Reproducible-Research-and-Data-Analysis)
4. [Open Research Data](https://github.com/OpenScienceMOOC/Module-4-Open-Research-Data)
5. [Open Research Software and Open Source](https://github.com/OpenScienceMOOC/Module-5-Open-Research-Software-and-Open-Source)
6. [Open Access to Research Papers](https://github.com/OpenScienceMOOC/Module-6-Open-Access-to-Research-Papers)
7. [Open Evaluation](https://github.com/OpenScienceMOOC/Module-7-Open-Evaluation)
8. [Public Engagement with Science](https://github.com/OpenScienceMOOC/Module-8-Public-Engagement-with-Science)
9. [Open Educational Resources](https://github.com/OpenScienceMOOC/Module-9-Open-Educational-Resources)
10. [Open Advocacy](https://github.com/OpenScienceMOOC/Module-10-Open-Advocacy)


## Forming a team for collaborative design

1. Hopefully, you've identified which module program to work on. It is probably best that you are already familiar with this topic. Building your core team is the next step. You will need a combination of:
   1. Experts. These will be your bread and butter. This can comprise people from any background, including academics, librarians, journalists, policymakers, librarians and information specialists, advocates, and students.
   2. It might also be useful to supplement this with learning designers, including those familiar with learning technologies.
   3. Being a trainer, educator, or educational expert is not a prerequisite. However, it would not hurt to have someone familiar with this on your team.
2. Having an initial briefing meeting will be the second step. This will be in conjunction with either a member of the MOOC Steering Committee, or if you're really unlucky, Jon. In this meeting, the following will be covered:
   1. An introduction to the MOOC, the managerial team, the core team, and an understanding of the requirements of each.
   2. Expectations of what each will contribute and receive from taking part.
   3. An explanation of time scales and commitments.
   4. An exploration of the MOOC module, the design and development protocol, the knowledge that will be included, and what the challenges to be addressed are.
   5. The core learning outcomes and mission objectives for the module. These are all defined in the [Proposed Modules](https://opensciencemooc.eu/modules/) section of the companion website for the MOOC.
3. Setting a timeline and action plan for development.
4. Acquiring team information. Each team member will be required to provide:
   1. A profile picture.
   2. A short bio.
   3. Twitter handle (where appropriate).
   4. Personal website (where appropriate).
5. Publicising the team to the MOOC companion website, [here](https://opensciencemooc.eu/people/#production).

## The development process

For a checkbox version of this, see the [MOOC planning template](MOOC_planning_template.md). This is design to keep track of the development in a structured manner.

1. Initiate and plan
   1. Define the target group  
   2. Refine the learning objectives and outcomes 
   3. Design the course outline 
       1. Combination of lectures, reading, and activities 
   4. Design the project plan and timeline 
   5. Identify promotion channels 
2. Designing and scripting
   1. Identify key resources (including those already gathered) 
   2. Design learner activities with clear instructions 
   3. Find resources (video, illustrations, screencasts, podcasts, assignments, quizzes, presentations) 
   4. Write concise, engaging video (and audio) scripts 
   5. Review all learning resources, adjusting as needed 
   6. Finalise all scripts 
   7. Copyright strategy 
3. Recording and editing
   1. Record either on location, online, or within studio 
   2. Preference to non-'floating head' styles 
   3. Edit all audio/visual material 
4. Quizzes and assignments
   1. First draft for feedback to instructional design 
   2. Follow up feedback 
   3. Define regularity of quizzes 
   4. Final examination 
   5. Review assignments  
   6. Other assignments (e.g., discussion prompts) 
5. Internal reviewing
   1. All members of team cross-review content 
   2. Checks from Steering Committee 
6. External testing and review 
   1. All content via GitHub 
   2. Use existing channels from communication strategy 
7. Internal reviewing and finalisation 
   1. All members of team cross-review content 
   2. Checks from Steering Committee 
8. Implementation 
   1. Agreement on platform 
   2. Module logo (either designed or copyright free) 
   3. Module description and introduction 
   4. Instructor and guest lecturer agreement 
   5. Instructor and team member profiles 
   6. Course readings all acquired (copyright free) 
   7. Port all content to selected platform 
   8. Make sure all content is also deposited in the Open Science Framework 
       1. For future indexing via Zenodo 
9. Promotion
   1. Content and communication calendar/strategy/timeline 
   2. Identify relevant channels, including:
       1. Mailing lists 
       2. Social media (including relevant hashtags) 
       3. Organisations 
       4. Individuals 
       5. Websites 
       6. Conferences 
   3. Images for use in social media 
   4. Course title marketing check  
10. Launch
    1. Publicity start 
    2. Open and free for all; continuous, self-paced learning; 100% online 
    3. Soft launch date 
    4. Course launch date 
    5. Monitor learner experiences and reactions 
    6. Prepare to provide additional information if required 
11. Reviewing and optimisation 
    1. Collate and review learner feedback at regular intervals 
    2. Track any potential new information during course duration 
    3. Prepare evaluation report 
    4. Evaluation meeting 
    5. Optimise content where relevant 